==> aliyun-python-sdk-ram-3.2.0.tar.gz: aliyun-python-sdk-ram-3.2.0/aliyunsdkram/request/v20150501/BindMFADeviceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkram.endpoint import endpoint_data

class BindMFADeviceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ram', '2015-05-01', 'BindMFADevice','Ram')
		self.set_protocol_type('https')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_SerialNumber(self):
		return self.get_query_params().get('SerialNumber')

	def set_SerialNumber(self,SerialNumber):
		self.add_query_param('SerialNumber',SerialNumber)

	def get_AuthenticationCode2(self):
		return self.get_query_params().get('AuthenticationCode2')

	def set_AuthenticationCode2(self,AuthenticationCode2):
		self.add_query_param('AuthenticationCode2',AuthenticationCode2)

	def get_AuthenticationCode1(self):
		return self.get_query_params().get('AuthenticationCode1')

	def set_AuthenticationCode1(self,AuthenticationCode1):
		self.add_query_param('AuthenticationCode1',AuthenticationCode1)

	def get_UserName(self):
		return self.get_query_params().get('UserName')

	def set_UserName(self,UserName):
		self.add_query_param('UserName',UserName)

==> aliyun-python-sdk-ram-3.3.0.tar.gz: aliyun-python-sdk-ram-3.3.0/aliyunsdkram/request/v20150501/BindMFADeviceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkram.endpoint import endpoint_data

class BindMFADeviceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ram', '2015-05-01', 'BindMFADevice','Ram')
		self.set_protocol_type('https')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_AuthenticationCode2(self): # String
		return self.get_query_params().get('AuthenticationCode2')

	def set_AuthenticationCode2(self, AuthenticationCode2):  # String
		self.add_query_param('AuthenticationCode2', AuthenticationCode2)
	def get_AuthenticationCode1(self): # String
		return self.get_query_params().get('AuthenticationCode1')

	def set_AuthenticationCode1(self, AuthenticationCode1):  # String
		self.add_query_param('AuthenticationCode1', AuthenticationCode1)
	def get_SerialNumber(self): # String
		return self.get_query_params().get('SerialNumber')

	def set_SerialNumber(self, SerialNumber):  # String
		self.add_query_param('SerialNumber', SerialNumber)
	def get_UserName(self): # String
		return self.get_query_params().get('UserName')

	def set_UserName(self, UserName):  # String
		self.add_query_param('UserName', UserName)
